import { jsx as _jsx } from "react/jsx-runtime";
import { useImperativeHandle, forwardRef } from 'react';
import { DiffEditor } from '@monaco-editor/react';
import { useTheme } from 'next-themes';
import { useSchemaServices } from './use-schema-services';
function BaseSchemaDiffEditor(props, forwardedRef) {
    const { theme } = useTheme();
    const originalSchemaService = useSchemaServices(props);
    const modifiedSchemaService = useSchemaServices(props);
    useImperativeHandle(forwardedRef, () => ({
        original: originalSchemaService.editorApi,
        modified: originalSchemaService.editorApi,
    }), [
        originalSchemaService.editorRef,
        modifiedSchemaService.editorRef,
        originalSchemaService.languageService,
        modifiedSchemaService.languageService,
    ]);
    return (_jsx(DiffEditor, { height: "70vh", theme: theme === 'dark' ? 'vs-dark' : 'light', ...props, beforeMount: monaco => {
            var _a;
            originalSchemaService.setMonaco(monaco);
            modifiedSchemaService.setMonaco(monaco);
            (_a = props.beforeMount) === null || _a === void 0 ? void 0 : _a.call(props, monaco);
        }, onMount: (editor, monaco) => {
            var _a;
            originalSchemaService.setEditor(editor.getOriginalEditor());
            modifiedSchemaService.setEditor(editor.getModifiedEditor());
            (_a = props.onMount) === null || _a === void 0 ? void 0 : _a.call(props, editor, monaco);
        }, options: { glyphMargin: true, ...props.options }, language: "graphql" }));
}
export const SchemaDiffEditor = forwardRef(BaseSchemaDiffEditor);
