import { jsx as _jsx } from "react/jsx-runtime";
import { useImperativeHandle, useEffect, useState, forwardRef, useCallback } from 'react';
import MonacoEditor from '@monaco-editor/react';
import { GraphQLError } from 'graphql';
import { useTheme } from 'next-themes';
import { useSchemaServices } from './use-schema-services';
function BaseSchemaEditor(props, ref) {
    const { theme } = useTheme();
    const { languageService, setMonaco, setEditor, editorApi, editorRef, setSchema } = useSchemaServices(props);
    useImperativeHandle(ref, () => editorApi, [editorRef, languageService]);
    useEffect(() => {
        if (languageService && props.onLanguageServiceReady) {
            props.onLanguageServiceReady(languageService);
        }
    }, [languageService, props.onLanguageServiceReady]);
    const [onBlurHandler, setOnBlurSubscription] = useState();
    useEffect(() => {
        if (editorRef && props.onBlur) {
            onBlurHandler === null || onBlurHandler === void 0 ? void 0 : onBlurHandler.dispose();
            const subscription = editorRef.onDidBlurEditorText(() => {
                var _a;
                (_a = props.onBlur) === null || _a === void 0 ? void 0 : _a.call(props, editorRef.getValue() || '');
            });
            setOnBlurSubscription(subscription);
        }
    }, [props.onBlur, editorRef]);
    const handleBeforeMount = useCallback(monaco => {
        var _a;
        setMonaco(monaco);
        (_a = props.beforeMount) === null || _a === void 0 ? void 0 : _a.call(props, monaco);
    }, [props.beforeMount]);
    const handleMount = useCallback((editor, monaco) => {
        var _a;
        setEditor(editor);
        (_a = props.onMount) === null || _a === void 0 ? void 0 : _a.call(props, editor, monaco);
    }, [props.onMount]);
    const handleChange = useCallback(async (newValue, ev) => {
        var _a, _b;
        (_a = props.onChange) === null || _a === void 0 ? void 0 : _a.call(props, newValue, ev);
        if (!newValue) {
            return;
        }
        try {
            const schema = await setSchema(newValue);
            if (schema) {
                (_b = props.onSchemaChange) === null || _b === void 0 ? void 0 : _b.call(props, schema, newValue);
            }
        }
        catch (e) {
            if (!props.onSchemaError) {
                return;
            }
            const error = e instanceof GraphQLError
                ? e
                : new GraphQLError(e.message, undefined, undefined, undefined, undefined, e);
            props.onSchemaError([error], newValue, languageService);
        }
    }, [props.onChange, props.onSchemaChange, props.onSchemaError]);
    return (_jsx(MonacoEditor, { height: "70vh", theme: theme === 'dark' ? 'vs-dark' : 'light', ...props, beforeMount: handleBeforeMount, onMount: handleMount, onChange: handleChange, options: { glyphMargin: true, ...props.options }, language: "graphql", defaultValue: props.defaultValue || props.schema }));
}
export const SchemaEditor = forwardRef(BaseSchemaEditor);
